
# Sponfiss

This is a simple python library containing a few quality of life functions when dealing with spontaneous fission reaction, calculations.



## Installation

```bash
pip install sponfiss
```

## Usage

Usage examples can be found in examplenotebook.ipynb

## Tests

test can be found under test folder

## License

[MIT](LICENSE)